@@ -3,8 +3,9 @@ from .SettingPropertyHandler import makeSettingPropertyHandler
 from vortex.handler.TupleDataObservableHandler import TupleDataObservableHandler
 
 
-def makeAdminBackendHandlers(tupleObservable: TupleDataObservableHandler,
-                             dbSessionCreator):
+def makeAdminBackendHandlers(
+    tupleObservable: TupleDataObservableHandler, dbSessionCreator
+):
     yield makeBranchDetailTupleHandler(tupleObservable, dbSessionCreator)
 
     yield makeSettingPropertyHandler(dbSessionCreator)
