@@ -1,19 +1,16 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {branchTuplePrefix} from "./_private/PluginNames";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { branchTuplePrefix } from "./_private/PluginNames";
 
 @addTupleType
 export class BranchDetailTuple extends Tuple {
     public static readonly tupleName = branchTuplePrefix + "BranchDetailTuple";
 
-
     /** The database ID
      *
      * Consider this field private
      */
     id: number;
 
-
     /** Model Set Key */
     modelSetKey: string;
 
@@ -54,6 +51,6 @@ export class BranchDetailTuple extends Tuple {
     createdDate: Date;
 
     constructor() {
-        super(BranchDetailTuple.tupleName)
+        super(BranchDetailTuple.tupleName);
     }
-}
\ No newline at end of file
+}
