@@ -1,4 +1,4 @@
-export let branchFilt = {"plugin": "peek_plugin_branch"};
+export let branchFilt = { plugin: "peek_plugin_branch" };
 export let branchTuplePrefix = "peek_plugin_branch.";
 
 export let branchObservableName = "peek_plugin_branch";
