@@ -1,6 +1,6 @@
-import {addTupleType, TupleActionABC} from "@synerty/vortexjs";
-import {branchTuplePrefix} from "../PluginNames";
-import {BranchDetailTuple} from "../../BranchDetailTuple";
+import { addTupleType, TupleActionABC } from "@synerty/vortexjs";
+import { branchTuplePrefix } from "../PluginNames";
+import { BranchDetailTuple } from "../../BranchDetailTuple";
 
 @addTupleType
 export class CreateBranchActionTuple extends TupleActionABC {
@@ -10,6 +10,6 @@ export class CreateBranchActionTuple extends TupleActionABC {
     offset: number;
 
     constructor() {
-        super(CreateBranchActionTuple.tupleName)
+        super(CreateBranchActionTuple.tupleName);
     }
-}
\ No newline at end of file
+}
