@@ -7,11 +7,12 @@ from peek_plugin_branch._private.PluginNames import branchTuplePrefix
 
 @addTupleType
 class BranchDetailTuple(Tuple):
-    """ Branch Tuple
+    """Branch Tuple
 
     This tuple is a create example of defining classes to work with our data.
     """
-    __tupleType__ = branchTuplePrefix + 'BranchDetailTuple'
+
+    __tupleType__ = branchTuplePrefix + "BranchDetailTuple"
 
     LOCATION_SERVER_BRANCH = 1
     LOCATION_LOCAL_BRANCH = 2
@@ -23,31 +24,31 @@ class BranchDetailTuple(Tuple):
     modelSetKey: str = TupleField()
 
     #: Key
-    # 
+    #
     # The key of this branch
     key: str = TupleField()
 
     #: Name
-    # 
+    #
     # The location of this branch
     name: str = TupleField()
 
     #: Comment
-    # 
+    #
     # The location of this branch
     comment: str = TupleField()
 
     #: User
-    # 
+    #
     # The location of this branch
     userName: str = TupleField()
 
     #: Updated Date
-    # 
+    #
     # The location of this branch
     updatedDate: datetime = TupleField()
 
     #: Created Date
-    # 
+    #
     # The location of this branch
     createdDate: datetime = TupleField()
